==> video_embed_field_plyr-8.x-1.0.tar.gz: video_embed_field_plyr/src/Plugin/Field/FieldFormatter/Plyr.php <==
<?php

namespace Drupal\video_embed_field_plyr\Plugin\Field\FieldFormatter;

use Drupal\Component\Utility\Html;


use Drupal\Component\Utility\NestedArray;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\video_embed_field\ProviderManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;


/**
 * Plugin implementation of the 'video_embed_field_plyr' formatter.
 *
 * @FieldFormatter(
 *   id = "video_embed_field_plyr",
 *   label = @Translation("Video (plyr)"),
 *   field_types = {
 *     "video_embed_field"
 *   }
 * )
 */
class Plyr extends FormatterBase implements ContainerFactoryPluginInterface {

  protected $providerManager;

  /**
   * The logged in user.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $currentUser;

  /**
   * Constructs a new instance of the plugin.
   *
   * @param string $plugin_id
   *   The plugin_id for the formatter.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Field\FieldDefinitionInterface $field_definition
   *   The definition of the field to which the formatter is associated.
   * @param array $settings
   *   The formatter settings.
   * @param string $label
   *   The formatter label display setting.
   * @param string $view_mode
   *   The view mode.
   * @param array $third_party_settings
   *   Third party settings.
   * @param \Drupal\video_embed_field\ProviderManagerInterface $provider_manager
   *   The video embed provider manager.
   */
  public function __construct($plugin_id, $plugin_definition, FieldDefinitionInterface $field_definition, $settings, $label, $view_mode, $third_party_settings, ProviderManagerInterface $provider_manager) {
    parent::__construct($plugin_id, $plugin_definition, $field_definition, $settings, $label, $view_mode, $third_party_settings);
    $this->providerManager = $provider_manager;
  }

  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $plugin_id,
      $plugin_definition,
      $configuration['field_definition'],
      $configuration['settings'],
      $configuration['label'],
      $configuration['view_mode'],
      $configuration['third_party_settings'],
      $container->get('video_embed_field.provider_manager')
    );
  }


  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $element = [];
    foreach ($items as $delta => $item) {
      $provider = $this->providerManager->loadProviderFromInput($item->value);
      if (!$provider) {
        $element[$delta] = ['#theme' => 'video_embed_field_missing_provider'];
      }
      else {
        // Should this be configurable?
        $embedCode = $provider->renderEmbedCode(1920, 1080, FALSE);
        $element[$delta] = [
          '#theme' => 'video_embed_plyr',
          '#videoId' => $provider::getIdFromInput($item->value),
          '#url' => $embedCode['#url'],
          '#provider' => $embedCode['#provider'],
          '#attributes' => [
            'id' => Html::getUniqueId('video-embed-plyr-' . $delta),
            'class' => [Html::cleanCssIdentifier('video-embed-field-plyr')],
          ],
          '#plyr_settings' => $this->buildPlyrDrupalSettings(),
          '#children' => $embedCode,
        ];

        if (TRUE === $this->settings['advanced']['polyfilled']) {
          $element[$delta]['#attached']['library'][] = 'video_embed_field_plyr/video_embed_field_plyr.polyfilled';
        }
        else {
          $element[$delta]['#attached']['library'][] = 'video_embed_field_plyr/video_embed_field_plyr.modern';
        }
        if (TRUE === $this->settings['advanced']['rangetouch']) {
          $element[$delta]['#attached']['library'][] = 'video_embed_field_plyr/video_embed_field_plyr.rangetouch';
        }
        $element[$delta]['#attached']['library'][] = 'video_embed_field_plyr/video_embed_field_plyr.drupal';
      }
    }
    return $element;
  }


  /**
   * Build the settings array that is passed to the Twig template
   * to build up the data-attributes per player instance.
   *
   * @return array
   */
  private function buildPlyrDrupalSettings() {
    $settings = [];
    foreach ($this->settings as $settingName => $settingValue) {
      if ($settingName === 'controls') {
        $controls = [];
        foreach ($settingValue as $controlName => $controlValue) {
          if (((bool) $controlValue)) {
            $controls[] = $controlName;
          }
        }
        $settings['controls'] = $controls;
      }
      elseif ((bool) $settingValue) {
        $settings[$settingName] = TRUE;
      }
    }
    return $settings;

  }


  public static function defaultSettings() {
    return [
      'autoplay' => FALSE,
      'resetOnEnd' => TRUE,
      'hideControls' => TRUE,
      'controls' => [
        'play-large' => FALSE,
        'play' => TRUE,
        'progress' => TRUE,
        'current-time' => TRUE,
        'mute' => TRUE,
        'volume' => TRUE,
        'settings' => TRUE,
        'captions' => FALSE,
        'airplay' => FALSE,
        'fullscreen' => TRUE,
      ],
      'advanced' => [
        'polyfilled' => TRUE,
        'rangetouch' => TRUE,
      ],
    ];
  }

  public function settingsForm(array $form, FormStateInterface $form_state) {
    $elements = parent::settingsForm($form, $form_state);
    $settings = $this->getSettings();

    $elements['autoplay'] = [
      '#title' => $this->t('Autoplay'),
      '#type' => 'checkbox',
      '#description' => $this->t('Autoplay the media on load. This is generally advised against on UX grounds. It is also disabled by default in some browsers.'),
      '#default_value' => $settings['autoplay'],
    ];
    $elements['resetOnEnd'] = [
      '#title' => $this->t('Reset on end'),
      '#type' => 'checkbox',
      '#description' => $this->t('Reset the playback to the start once playback is complete.'),
      '#default_value' => $settings['resetOnEnd'],
    ];
    $elements['hideControls'] = [
      '#title' => $this->t('Hide controls'),
      '#type' => 'checkbox',
      '#description' => $this->t('Hide video controls automatically after 2s of no mouse or focus movement, on control element blur (tab out), on playback start or entering fullscreen.'),
      '#default_value' => $settings['hideControls'],
    ];
    $elements['controls'] = [
      '#title' => $this->t('Plyr Controls'),
      '#type' => 'fieldset',
    ];

    $elements['controls']['play'] = [
      '#title' => $this->t('Play'),
      '#type' => 'checkbox',
      '#description' => $this->t('Show play/pause button'),
      '#default_value' => $settings['controls']['play'],
    ];

    $elements['controls']['play-large'] = [
      '#title' => $this->t('Play large'),
      '#type' => 'checkbox',
      '#description' => $this->t('Show large play button'),
      '#default_value' => $settings['controls']['play-large'],
    ];

    $elements['controls']['mute'] = [
      '#title' => $this->t('Mute'),
      '#type' => 'checkbox',
      '#description' => $this->t('Show toggle mute button'),
      '#default_value' => $settings['controls']['mute'],
    ];
    $elements['controls']['airplay'] = [
      '#title' => $this->t('Airplay'),
      '#type' => 'checkbox',
      '#description' => $this->t('Enable airplay'),
      '#default_value' => $settings['controls']['airplay'],
    ];
    $elements['controls']['fullscreen'] = [
      '#title' => $this->t('Fullscreen'),
      '#type' => 'checkbox',
      '#description' => $this->t('Allow fullscreen playback'),
      '#default_value' => $settings['controls']['fullscreen'],
    ];
    $elements['controls']['progress'] = [
      '#title' => $this->t('Progress'),
      '#type' => 'checkbox',
      '#description' => $this->t('Show progress bar'),
      '#default_value' => $settings['controls']['progress'],
    ];
    $elements['controls']['volume'] = [
      '#title' => $this->t('Volume'),
      '#type' => 'checkbox',
      '#description' => $this->t('Show volume controls'),
      '#default_value' => $settings['controls']['volume'],
    ];

    $elements['controls']['current-time'] = [
      '#title' => $this->t('Current time'),
      '#type' => 'checkbox',
      '#description' => $this->t('Show current time of playback'),
      '#default_value' => $settings['controls']['current-time'],
    ];

    $elements['controls']['settings'] = [
      '#title' => $this->t('Quality settings'),
      '#type' => 'checkbox',
      '#description' => $this->t('Playback quality settings'),
      '#default_value' => $settings['controls']['settings'],
    ];
    $elements['advanced'] = [
      '#title' => $this->t('Advanced settings'),
      '#type' => 'fieldset',
    ];

    $elements['advanced']['polyfilled'] = [
      '#title' => $this->t('Use polyfilled version'),
      '#type' => 'checkbox',
      '#description' => $this->t('Use the IE11 polyfilled version'),
      '#default_value' => $settings['advanced']['polyfilled'],
    ];
    $elements['advanced']['rangetouch'] = [
      '#title' => $this->t('Add RangeTouch library'),
      '#type' => 'checkbox',
      '#description' => $this->t('This improves `input type="range"` on mobile devices.'),
      '#default_value' => $settings['advanced']['rangetouch'],
    ];

    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $settings = $this->getSettings();

    $global = [];
    if (TRUE === (bool) $settings['autoplay']) {
      $global[] = $this->t('Autoplaying');
    }
    if (TRUE === (bool) $settings['resetOnEnd']) {
      $global[] = $this->t('Reset on end');
    }
    if (TRUE === (bool) $settings['hideControls']) {
      $global[] = $this->t('auto hide control');
    }
    if (TRUE === (bool) $settings['advanced']['polyfilled']) {
      $global[] = $this->t('Polyfilled version');
    } else {
        $global[] = $this->t('Modern version');
    }
    if (TRUE === (bool) $settings['advanced']['rangetouch']) {
      $global[] = $this->t('RangeTouch enabled');
    }
    $controls = [];
    foreach ($settings['controls'] as $name => $value) {
      if (TRUE === (bool) $value) {
        $controls[] = $this->t(ucfirst($name));
      }
    }
    $summary = [];
    $summary[] = $this->t('@global', ['@global' => implode(', ', $global)]);
    $summary[] = $this->t('Controls: @controls', ['@controls' => implode(', ', $controls)]);
    return $summary;
  }

}

==> video_embed_field_plyr-8.x-1.1.tar.gz: video_embed_field_plyr/src/Plugin/Field/FieldFormatter/Plyr.php <==
<?php

namespace Drupal\video_embed_field_plyr\Plugin\Field\FieldFormatter;

use Drupal\Component\Utility\Html;

use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\video_embed_field\ProviderManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;


/**
 * Plugin implementation of the 'video_embed_field_plyr' formatter.
 *
 * @FieldFormatter(
 *   id = "video_embed_field_plyr",
 *   label = @Translation("Video (plyr)"),
 *   field_types = {
 *     "video_embed_field"
 *   }
 * )
 */
class Plyr extends FormatterBase implements ContainerFactoryPluginInterface
{

  protected $providerManager;

  /**
   * The logged in user.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $currentUser;

  /**
   * Constructs a new instance of the plugin.
   *
   * @param string $plugin_id
   *   The plugin_id for the formatter.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Field\FieldDefinitionInterface $field_definition
   *   The definition of the field to which the formatter is associated.
   * @param array $settings
   *   The formatter settings.
   * @param string $label
   *   The formatter label display setting.
   * @param string $view_mode
   *   The view mode.
   * @param array $third_party_settings
   *   Third party settings.
   * @param \Drupal\video_embed_field\ProviderManagerInterface $provider_manager
   *   The video embed provider manager.
   */
  public function __construct($plugin_id, $plugin_definition, FieldDefinitionInterface $field_definition, $settings, $label, $view_mode, $third_party_settings, ProviderManagerInterface $provider_manager)
  {
    parent::__construct($plugin_id, $plugin_definition, $field_definition, $settings, $label, $view_mode, $third_party_settings);
    $this->providerManager = $provider_manager;
  }

  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition)
  {
    return new static(
      $plugin_id,
      $plugin_definition,
      $configuration['field_definition'],
      $configuration['settings'],
      $configuration['label'],
      $configuration['view_mode'],
      $configuration['third_party_settings'],
      $container->get('video_embed_field.provider_manager')
    );
  }


  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode)
  {
    $element = [];
    foreach ($items as $delta => $item) {
      $provider = $this->providerManager->loadProviderFromInput($item->value);
      if (!$provider) {
        $element[$delta] = ['#theme' => 'video_embed_field_missing_provider'];
      } else {
        // Should this be configurable?
        $embedCode = $provider->renderEmbedCode(1920, 1080, FALSE);
        $element[$delta] = [
          '#theme' => 'video_embed_plyr',
          '#videoId' => $provider::getIdFromInput($item->value),
          '#url' => $embedCode['#url'],
          '#provider' => $embedCode['#provider'],
          '#attributes' => [
            'id' => Html::getUniqueId('video-embed-plyr-' . $delta),
            'class' => [Html::cleanCssIdentifier('video-embed-field-plyr')],
          ],
          '#plyr_settings' => $this->buildPlyrDrupalSettings(),
          '#children' => $embedCode,
        ];


        if (TRUE === (bool) $this->settings['advanced']['polyfilled']) {
          $element[$delta]['#attached']['library'][] = 'video_embed_field_plyr/video_embed_field_plyr.polyfilled';
        } else {
          $element[$delta]['#attached']['library'][] = 'video_embed_field_plyr/video_embed_field_plyr.modern';
        }
        if (TRUE === (bool) $this->settings['advanced']['rangetouch']) {
          $element[$delta]['#attached']['library'][] = 'video_embed_field_plyr/video_embed_field_plyr.rangetouch';
        }
        $element[$delta]['#attached']['library'][] = 'video_embed_field_plyr/video_embed_field_plyr.drupal';
      }
    }
    return $element;
  }


  /**
   * Build the settings array that is passed to the Twig template
   * to build up the data-attributes per player instance.
   *
   * @return array
   */
  private function buildPlyrDrupalSettings()
  {
    $settings = [];
    foreach ($this->settings as $settingName => $settingValue) {
      if ($settingName === 'controls') {
        $controls = [];
        foreach ($settingValue as $controlName => $controlValue) {
          if (((bool)$controlValue)) {
            $controls[] = $controlName;
          }
        }
        $settings['controls'] = $controls;
      }
      elseif ($settingName === 'youtube') {
        $youTube = new \stdClass();
        foreach ($settingValue as $controlName => $controlValue) {
          if (((bool)$controlValue)) {
            $youTube->{$controlName} = (bool) $controlValue;
          }
        }
        $settings['youtube'] = $youTube;
      }

      elseif ((bool)$settingValue) {
        $settings[$settingName] = TRUE;
      }
    }
    return $settings;

  }


  public static function defaultSettings()
  {
    return [
      'autoplay' => FALSE,
      'resetOnEnd' => TRUE,
      'hideControls' => TRUE,
      'controls' => [
        'play-large' => FALSE,
        'play' => TRUE,
        'restart' => FALSE,
        'fast-forward' => FALSE,
        'progress' => TRUE,
        'current-time' => TRUE,
        'duration' => FALSE,
        'mute' => TRUE,
        'volume' => TRUE,
        'settings' => TRUE,
        'captions' => FALSE,
        'airplay' => FALSE,
        'fullscreen' => TRUE,
        'pip' => FALSE,
      ],
      'advanced' => [
        'polyfilled' => TRUE,
        'rangetouch' => TRUE,
      ],
      'youtube' => [
        'noCookie' => TRUE,
      ]
    ];
  }

  public function settingsForm(array $form, FormStateInterface $form_state)
  {
    $elements = parent::settingsForm($form, $form_state);
    $settings = $this->getSettings();

    $elements['autoplay'] = [
      '#title' => $this->t('Autoplay'),
      '#type' => 'checkbox',
      '#description' => $this->t('Autoplay the media on load. This is generally advised against on UX grounds. It is also disabled by default in some browsers.'),
      '#default_value' => $settings['autoplay'],
    ];
    $elements['resetOnEnd'] = [
      '#title' => $this->t('Reset on end'),
      '#type' => 'checkbox',
      '#description' => $this->t('Reset the playback to the start once playback is complete.'),
      '#default_value' => $settings['resetOnEnd'],
    ];
    $elements['hideControls'] = [
      '#title' => $this->t('Hide controls'),
      '#type' => 'checkbox',
      '#description' => $this->t('Hide video controls automatically after 2s of no mouse or focus movement, on control element blur (tab out), on playback start or entering fullscreen.'),
      '#default_value' => $settings['hideControls'],
    ];
    $elements['controls'] = [
      '#title' => $this->t('Plyr Controls'),
      '#type' => 'fieldset',
    ];

    $elements['controls']['play'] = [
      '#title' => $this->t('Play'),
      '#type' => 'checkbox',
      '#description' => $this->t('Show play/pause button'),
      '#default_value' => $settings['controls']['play'],
    ];

    $elements['controls']['play-large'] = [
      '#title' => $this->t('Play large'),
      '#type' => 'checkbox',
      '#description' => $this->t('Show large play button'),
      '#default_value' => $settings['controls']['play-large'],
    ];

    $elements['controls']['restart'] = [
      '#title' => $this->t('Restart'),
      '#type' => 'checkbox',
      '#description' => $this->t('Restart playback'),
      '#default_value' => $settings['controls']['restart'],
    ];

    $elements['controls']['fast-forward'] = [
      '#title' => $this->t('Fast forward'),
      '#type' => 'checkbox',
      '#description' => $this->t('Fast forward by 10 seconds'),
      '#default_value' => $settings['controls']['fast-forward'],
    ];


    $elements['controls']['mute'] = [
      '#title' => $this->t('Mute'),
      '#type' => 'checkbox',
      '#description' => $this->t('Show toggle mute button'),
      '#default_value' => $settings['controls']['mute'],
    ];

    $elements['controls']['airplay'] = [
      '#title' => $this->t('Airplay'),
      '#type' => 'checkbox',
      '#description' => $this->t('Enable airplay'),
      '#default_value' => $settings['controls']['airplay'],
    ];

    $elements['controls']['pip'] = [
      '#title' => $this->t('Picture-in-picture'),
      '#type' => 'checkbox',
      '#description' => $this->t('Picture-in-picture (limited browser support)'),
      '#default_value' => $settings['controls']['pip'],
    ];

    $elements['controls']['fullscreen'] = [
      '#title' => $this->t('Fullscreen'),
      '#type' => 'checkbox',
      '#description' => $this->t('Allow fullscreen playback'),
      '#default_value' => $settings['controls']['fullscreen'],
    ];
    $elements['controls']['progress'] = [
      '#title' => $this->t('Progress'),
      '#type' => 'checkbox',
      '#description' => $this->t('Show progress bar'),
      '#default_value' => $settings['controls']['progress'],
    ];
    $elements['controls']['volume'] = [
      '#title' => $this->t('Volume'),
      '#type' => 'checkbox',
      '#description' => $this->t('Show volume controls'),
      '#default_value' => $settings['controls']['volume'],
    ];

    $elements['controls']['current-time'] = [
      '#title' => $this->t('Current time'),
      '#type' => 'checkbox',
      '#description' => $this->t('Show current time of playback'),
      '#default_value' => $settings['controls']['current-time'],
    ];

    $elements['controls']['duration'] = [
      '#title' => $this->t('Duration'),
      '#type' => 'checkbox',
      '#description' => $this->t('Show duration if available'),
      '#default_value' => $settings['controls']['duration'],
    ];

    $elements['controls']['settings'] = [
      '#title' => $this->t('Quality settings'),
      '#type' => 'checkbox',
      '#description' => $this->t('Playback quality settings'),
      '#default_value' => $settings['controls']['settings'],
    ];
    $elements['advanced'] = [
      '#title' => $this->t('Advanced settings'),
      '#type' => 'fieldset',
    ];

    $elements['advanced']['polyfilled'] = [
      '#title' => $this->t('Use polyfilled version'),
      '#type' => 'checkbox',
      '#description' => $this->t('Use the IE11 polyfilled version'),
      '#default_value' => $settings['advanced']['polyfilled'],
    ];
    $elements['advanced']['rangetouch'] = [
      '#title' => $this->t('Add RangeTouch library'),
      '#type' => 'checkbox',
      '#description' => $this->t('This improves `input type="range"` on mobile devices.'),
      '#default_value' => $settings['advanced']['rangetouch'],
    ];

    $elements['youtube'] = [
      '#title' => $this->t('YouTube settings'),
      '#type' => 'fieldset',
    ];

    $elements['youtube']['noCookie'] = [
      '#title' => $this->t('No cookie player'),
      '#type' => 'checkbox',
      '#description' => $this->t('Use the no Cookie YouTube player.'),
      '#default_value' => $settings['youtube']['noCookie'],
    ];

    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary()
  {
    $settings = $this->getSettings();

    $global = [];
    if (TRUE === (bool)$settings['autoplay']) {
      $global[] = $this->t('Autoplaying');
    }
    if (TRUE === (bool)$settings['resetOnEnd']) {
      $global[] = $this->t('Reset on end');
    }
    if (TRUE === (bool)$settings['hideControls']) {
      $global[] = $this->t('auto hide control');
    }
    if (TRUE === (bool)$settings['advanced']['polyfilled']) {
      $global[] = $this->t('Polyfilled version');
    } else {
      $global[] = $this->t('Modern version');
    }
    if (TRUE === (bool)$settings['advanced']['rangetouch']) {
      $global[] = $this->t('RangeTouch enabled');
    }
    $controls = [];
    foreach ($settings['controls'] as $name => $value) {
      if (TRUE === (bool)$value) {
        $controls[] = $this->t(ucfirst($name));
      }
    }
    $summary = [];
    $summary[] = $this->t('@global', ['@global' => implode(', ', $global)]);
    $summary[] = $this->t('Controls: @controls', ['@controls' => implode(', ', $controls)]);
    return $summary;
  }

}
